@@ -119,6 +119,8 @@ class Components:
                         _options.append(str(option).zfill(5))
                     else:
                         _options.append(option)
+
+                code_list = _options
             else:
                 _options = checkbox_values[para_name]
 
@@ -129,13 +131,38 @@ class Components:
                                            labelStyle={},
                                            inputStyle={'margin-left': '10px', 'margin-right': '3px'})
             else:
-                _checklist = dcc.Checklist(_options, _options, inline=True,
-                                           id={'type': 'para-checklist', 'index': i},
-                                           labelStyle={'font-size': '12px'},
-                                           #label_checked_style={"color": "red"},
-                                           inputStyle={'margin-left': '10px', 'margin-right': '3px','background-color':'red',
-                                                       'vertical-align':'middle','position':'relative',
-                                                       'bottom':'.15em'})
+                if para_name == 'code':
+                    _checklist = dbc.Row([
+                        dcc.Checklist(
+                            id="all-or-none",
+                            options=[{"label": "Select All", "value": "All"}],
+                            labelStyle={'font-size': '12px'},
+                            inputStyle={'margin-left': '10px', 'margin-right': '3px',
+                                        'background-color': 'red',
+                                        'vertical-align': 'middle', 'position': 'relative',
+                                        'bottom': '.15em'}
+                        ),
+
+                        html.Div(style={'height': '5px'}),
+
+                        dcc.Checklist(_options, _options, inline=True,
+                                      id={'type': 'para-checklist', 'index': i},
+                                      labelStyle={'font-size': '12px'},
+                                      inputStyle={'margin-left': '10px', 'margin-right': '3px',
+                                                  'background-color': 'red',
+                                                  'vertical-align': 'middle', 'position': 'relative',
+                                                  'bottom': '.15em'})
+                    ])
+
+                else:
+                    _checklist = dcc.Checklist(_options, _options, inline=True,
+                                               id={'type': 'para-checklist', 'index': i},
+                                               labelStyle={'font-size': '12px'},
+                                               # label_checked_style={"color": "red"},
+                                               inputStyle={'margin-left': '10px', 'margin-right': '3px',
+                                                           'background-color': 'red',
+                                                           'vertical-align': 'middle', 'position': 'relative',
+                                                           'bottom': '.15em'})
             row = html.Div(
                 dbc.Row([
                     html.Div(para_name),
@@ -146,7 +173,7 @@ class Components:
 
             checkbox_div.append(row)
 
-        return checkbox_div
+        return checkbox_div, code_list
 
     def update_stat_div(self, period, pct_mean, rise_mean, fall_mean):
         div = html.Div([
